Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/libgit2sharp.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'LibGit2Sharp/StatusEntry.cs')
-rw-r--r--LibGit2Sharp/StatusEntry.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/LibGit2Sharp/StatusEntry.cs b/LibGit2Sharp/StatusEntry.cs
index ecf56dbe..1d62a098 100644
--- a/LibGit2Sharp/StatusEntry.cs
+++ b/LibGit2Sharp/StatusEntry.cs
@@ -58,7 +58,7 @@ namespace LibGit2Sharp
}
/// <summary>
/// Gets the rename details from the Index to the working directory, if this <see cref="FileStatus"/> contains <see cref="FileStatus.RenamedInWorkDir"/>
/// </summary>
public virtual RenameDetails IndexToWorkDirRenameDetails
{
@@ -121,7 +121,7 @@ namespace LibGit2Sharp
get
{
if ((State & FileStatus.RenamedInIndex) == FileStatus.RenamedInIndex ||
- (State & FileStatus.RenamedInWorkDir) == FileStatus.RenamedInWorkDir)
+ (State & FileStatus.RenamedInWorkdir) == FileStatus.RenamedInWorkdir)
{
string oldFilePath = ((State & FileStatus.RenamedInIndex) == FileStatus.RenamedInIndex) ?
HeadToIndexRenameDetails.OldFilePath : IndexToWorkDirRenameDetails.OldFilePath;
@@ -58,7 +58,7 @@ namespace LibGit2Sharp
}
/// <summary>
- /// Gets the rename details from the Index to the working directory, if this <see cref="FileStatus"/> contains <see cref="FileStatus.RenamedInWorkDir"/>
+ /// Gets the rename details from the Index to the working directory, if this <see cref="FileStatus"/> contains <see cref="FileStatus.RenamedInWorkdir"/>
/// </summary>
public virtual RenameDetails IndexToWorkDirRenameDetails